Learn R Programming

DIZtools (version 1.0.3)

close_all_connections: Unset/close all open connections.

Description

This function is meant to be called at the end of a run of the app. It will close all open connections to files or databases. This closes ALL connections. Not just the ones opened by this package.

Usage

close_all_connections()

Arguments

Value

No return value, called for side effects (see description)

Examples

Run this code
# \donttest{
close_all_connections()# }

Run the code above in your browser using DataLab