Learn R Programming

DIZtools (version 1.0.3)

number_to_position: Converts an integer number to its "verbal position". 1 --> "1st", 2 --> "2nd", 3 --> "3rd", 4 --> "4th", ...

Description

Converts an integer number to its "verbal position". 1 --> "1st", 2 --> "2nd", 3 --> "3rd", 4 --> "4th", ...

Usage

number_to_position(x)

Value

Returns the input number as string with a new suffix depending on the numbers position in the numbers bar.

Arguments

x

A number.

Examples

Run this code
{

}

Run the code above in your browser using DataLab