file_lines_to_list: Read in lines from a file and store it in a list.
Description
Read in lines from a file and store it in a list.
Usage
file_lines_to_list(filepath)
Value
A list with one element per row of the input file
Arguments
- filepath
(string) Path to file to read in.