powered by
Converts an integer number to its "verbal position". 1 --> "1st", 2 --> "2nd", 3 --> "3rd", 4 --> "4th", ...
number_to_position(x)
Returns the input number as string with a new suffix depending on the numbers position in the numbers bar.
A number.
{ }
Run the code above in your browser using DataLab